@@ -1,7 +1,7 @@
 package Data::Dmp;
 
-our $DATE = '2016-10-26'; # DATE
-our $VERSION = '0.21'; # VERSION
+our $DATE = '2017-01-30'; # DATE
+our $VERSION = '0.23'; # VERSION
 
 use 5.010001;
 use strict;
@@ -21,6 +21,7 @@ our @_fixups;
 our $OPT_PERL_VERSION = "5.010";
 our $OPT_REMOVE_PRAGMAS = 0;
 our $OPT_DEPARSE = 1;
+our $OPT_STRINGIFY_NUMBERS = 0;
 
 # BEGIN COPY PASTE FROM Data::Dump
 my %esc = (
@@ -82,6 +83,11 @@ sub _dump_code {
     $res;
 }
 
+sub _quote_key {
+    $_[0] =~ /\A-?[A-Za-z_][A-Za-z0-9_]*\z/ ||
+        $_[0] =~ /\A-?[1-9][0-9]{0,8}\z/ ? $_[0] : _double_quote($_[0]);
+}
+
 sub _dump {
     my ($val, $subscript) = @_;
 
@@ -89,7 +95,7 @@ sub _dump {
     if ($ref eq '') {
         if (!defined($val)) {
             return "undef";
-        } elsif (looks_like_number($val) &&
+        } elsif (looks_like_number($val) && !$OPT_STRINGIFY_NUMBERS &&
                      # perl does several normalizations to number literal, e.g.
                      # "+1" becomes 1, 0123 is octal literal, etc. make sure we
                      # only leave out quote when the number is not normalized
@@ -140,9 +146,7 @@ sub _dump {
         my $i = 0;
         for (sort keys %$val) {
             $res .= "," if $i++;
-            my $k =
-                /\A-?[A-Za-z_][A-Za-z0-9_]*\z/ ||
-                /\A-?[1-9][0-9]{0,8}\z/ ? $_ : _double_quote($_);
+            my $k = _quote_key($_);
             my $v = _dump($val->{$_}, "$subscript\{$k}");
             $res .= "$k=>$v";
         }
@@ -203,7 +207,7 @@ Data::Dmp - Dump Perl data structures as Perl code
 
 =head1 VERSION
 
-This document describes version 0.21 of Data::Dmp (from Perl distribution Data-Dmp), released on 2016-10-26.
+This document describes version 0.23 of Data::Dmp (from Perl distribution Data-Dmp), released on 2017-01-30.
 
 =head1 SYNOPSIS
 
@@ -266,25 +270,31 @@ Note that without the pragmas, the dump might be incorrect.
 Can be set to 0 to skip deparsing code. Coderefs will be dumped as
 C<sub{"DUMMY"}> instead, like in Data::Dump.
 
+=head2 $Data::Dmp::OPT_STRINGIFY_NUMBERS => bool (default: 0)
+
+If set to true, will dump numbers as quoted string, e.g. 123 as "123" instead of
+123. This might be helpful if you want to compute the hash of or get a canonical
+representation of data structure.
+
 =head1 BENCHMARKS
 
  [1..10]:
-                      Rate    Data::Dump Data::Dumper Data::Dmp
- Data::Dump    23118+-26/s            --       -62.7%    -74.9%
- Data::Dumper  61897+-26/s 167.74+-0.32%           --    -32.8%
- Data::Dmp    92150+-110/s  298.6+-0.66% 48.87+-0.19%        --
+                       Rate    Data::Dump Data::Dumper Data::Dmp
+ Data::Dump     30417+-55/s            --       -66.2%    -74.0%
+ Data::Dumper   89888+-79/s  195.52+-0.6%           --    -23.1%
+ Data::Dmp    116890+-160/s 284.29+-0.87% 30.04+-0.21%        --
  
  [1..100]:
-                        Rate  Data::Dump   Data::Dmp Data::Dumper
- Data::Dump       2901+-16/s          --      -74.2%       -75.4%
- Data::Dmp    11264.4+-3.4/s 288.3+-2.2%          --        -4.4%
- Data::Dumper    11786+-78/s 306.3+-3.5% 4.63+-0.69%           --
+                        Rate    Data::Dump  Data::Dmp Data::Dumper
+ Data::Dump    3712.3+-7.9/s            --     -73.9%       -74.9%
+ Data::Dmp    14211.3+-4.9/s 282.82+-0.82%         --        -3.8%
+ Data::Dumper    14771+-28/s   297.9+-1.1% 3.94+-0.2%           --
  
  Some mixed structure:
-                      Rate  Data::Dump  Data::Dmp Data::Dumper
- Data::Dump     6132+-74/s          --     -66.9%       -81.3%
- Data::Dmp    18540+-200/s 202.4+-4.9%         --       -43.3%
- Data::Dumper  32722+-56/s 433.6+-6.5% 76.5+-1.9%           --
+                     Rate    Data::Dump    Data::Dmp Data::Dumper
+ Data::Dump    8764+-16/s            --       -67.6%       -80.1%
+ Data::Dmp    27016+-36/s  208.28+-0.7%           --       -38.6%
+ Data::Dumper 43995+-13/s 402.02+-0.95% 62.85+-0.22%           --
 
 =head1 FUNCTIONS
 
@@ -368,7 +378,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
